import { ChartDimensionRoleType, getChartCategory, getChartCategory2, getEntityHierarchy, getEntityLevel, getPropertyCaption } from '@metad/ocap-core';
import format from 'date-fns/format';
import parse from 'date-fns/parse';
import cloneDeep from 'lodash/cloneDeep';
import { coordinates, gatherCoordinates } from './coordinates';
export function themeRiver(data, chartAnnotation, entityType, settings, options) {
    // 智能补全信息
    const index = chartAnnotation.dimensions.findIndex((item) => item.role === ChartDimensionRoleType.Category2);
    if (index === -1) {
        chartAnnotation = cloneDeep(chartAnnotation);
        const dimension = chartAnnotation.dimensions.slice(1).find((item) => !item.role);
        dimension.role = ChartDimensionRoleType.Category2;
    }
    const coordinateDatas = coordinates(data, chartAnnotation, entityType, settings, options, 'grid', themeRiverCoordinate);
    return gatherCoordinates(coordinateDatas, 'themeRiver', options);
}
export function themeRiverCoordinate(data, chartAnnotation, entityType, settings, options) {
    const category = getChartCategory(chartAnnotation);
    // const categoryProperty = getEntityProperty(entityType, category)
    const categoryCaption = getPropertyCaption(getEntityHierarchy(entityType, category));
    const category2 = getChartCategory2(chartAnnotation);
    const measure = chartAnnotation.measures[0];
    const categoryLevelProperty = getEntityLevel(entityType, category);
    console.log(categoryLevelProperty);
    const formatter = categoryLevelProperty.semantics?.formatter || 'yyyyMMdd';
    return {
        name: '',
        datasets: [
            {
                series: [
                    {
                        data: data.map((item) => [
                            format(parse(item[categoryCaption], formatter, new Date()), 'yyyy/MM/dd'),
                            item[measure.measure],
                            item[category2.hierarchy]
                        ])
                    }
                ]
            }
        ],
        grid: {},
        xAxis: [],
        yAxis: [],
        singleAxis: [
            {
                type: 'time'
            }
        ],
        visualMap: [],
        tooltip: [],
        legend: []
    };
}
//# sourceMappingURL=themeRiver.js.map